# Mopidy Mobile Privacy Policy

This privacy policy covers the use of the "Mopidy Mobile" Android and
Web applications.

We do not collect any statistics, personal information, or analytics
from our users, other than built in mechanisms that are present for
all the mobile applications in their respective main distribution
channels.
